%--------------------------------------------------------------
%
% Taylor_sim.m
%
% Simulate the dynamic response of the model to specific shocks
%
% by: Guenter Coenen. 15 March 2000   
%
%--------------------------------------------------------------

clc
clear all

% ----------------------
% solve model for observable structure
% (only needs to be done once to create cofb and 
% other model variables)
% ----------------------



 
Taylor_run

% ----------------------
% set up matrices for dynamic simulation
% ----------------------

[neq,neqnlag] = size(cofb);

amat1 = cofb(1:neq,2*neq+1:3*neq);
amat2 = cofb(1:neq,neq+1:2*neq);
amat3 = cofb(1:neq,1:neq);

bmat = inv(scof(1:neq,3*neq+1:4*neq));
bmat = bmat(1:neq,1:neq);

% number of periods
np = 32;

% ----------------------
% initial conditions for endogenous variables
% ----------------------

   x(1:np,1:neq)=zeros(np,neq);                    
   for i = 1:np;                                   
      x(i,strmatch('is'    ,endog_))      = 0;     
      x(i,strmatch('il'    ,endog_))      = 0;     
      x(i,strmatch('rl'    ,endog_))      = 0;     
      x(i,strmatch('epi8'  ,endog_))      = 0;     
      x(i,strmatch('pi4'   ,endog_))      = 0;     
      x(i,strmatch('q'     ,endog_))      = 0;     
      x(i,strmatch('cwp'   ,endog_))      = 0;     
      x(i,strmatch('pi1'   ,endog_))      = 0;     
      x(i,strmatch('one'   ,endog_))      = 1;     
      x(i,strmatch('e_d'   ,endog_))      = 0;     
      x(i,strmatch('e_cw'  ,endog_))      = 0;     
   end;                                            
% ----------------------                                                                   
% initial conditions for exogenous shocks
% ----------------------

e_cw0 = zeros(np,1);
e_d0  = zeros(np,1);

%---------------------
% option to simulate dynamic
% response to one specific shock
%---------------------

type = 10;      % type =  8:  contract wage shock
               % type =  9:  output gap shock
               % type = 10:  disinflation scenario
               
% -----------------------
% simulations start in period nstart
% a shock occurs in period nshock
% -----------------------

nstart = 5;
nshock = 5;
              
%---------------------
% define shocks
%---------------------

if type == 8
   e_cw0(nshock) = 1.00;
elseif type == 9
   e_d0(nshock)   = 0.005/sigma_e_d;
elseif type == 10
   pitarget_t0 = 0.005;
   for i = 1:nstart-1;
      x(i,strmatch('is'    , endog_))    = pitarget_t0*4;
      x(i,strmatch('il'    , endog_))    = pitarget_t0*4;
      x(i,strmatch('epi8'  , endog_))    = pitarget_t0*4;
      x(i,strmatch('pi4'   , endog_))    = pitarget_t0*4;
      x(i,strmatch('cwp'   , endog_))    = ((0.25+0.5*s)+2*(0.25-0.5*s)+3*(0.25-1.5*s))*pitarget_t0;
      x(i,strmatch('pi1'   , endog_))    = pitarget_t0;
   end;
end   

e = zeros(np,neq);
e(:,strmatch('e_cw',endog_)) = e_cw0;
e(:,strmatch('e_d' ,endog_))  = e_d0;

% ----------------------
% dynamic simulation from initial conditions
% ----------------------

for i = nstart:np;
   x1 = x(i-1,1:neq)';
   x2 = x(i-2,1:neq)';
   x3 = x(i-3,1:neq)';
   ee = e(i,:)';
   xc = amat1*x1+amat2*x2+amat3*x3+bmat*ee;
   x(i,1:neq) = xc';
end

% ----------------------
% preparation for plotting and printout
% ----------------------

%number of periods for printout
nprint = np;

% x axis, for time series plots
n = 1:1:nprint;

% dynamic paths of endogenous variables
pi4    = x(1:nprint,strmatch('pi4',endog_));
q      = x(1:nprint,strmatch('q'  ,endog_));

subplot(2,2,1);
plot(n,pi4,'b-');
title('Inflation');
if (type == 8) | (type == 9)
   axis([1 nprint -0.005 0.01]);
elseif type == 10
   axis([1 nprint -0.005 0.025]);
end

subplot(2,2,2);
plot(n,q,'b-');
title('Output Gap');
if (type == 8) | (type == 9)
   axis([1 nprint -0.005 0.01]);
elseif type == 10
   axis([1 nprint -0.005 0.005]);
end

pause
close

eval(['Fig',int2str(type),'_NW = [pi4 q];']);
eval(['save Fig',int2str(type),'_NW Fig',int2str(type),'_NW'])
